@@ -7,7 +7,8 @@ from .main import DynamoDBGlobalConfiguration  # noqa: F401
 from .main import MultiTableDynamoCrudRepository  # noqa: F401
 from .main import Repository  # noqa: F401
 from .main import SingleTableDynamoCrudRepository  # noqa: F401
-from .main import dynamo_entity  # noqa: F401; noqa: F401
+from .main import SortKeyComparator  # noqa: F401
+from .main import dynamo_entity  # noqa: F401
 
-__version__ = "0.3.17"
+__version__ = "0.3.39"
 __author__ = """DRUID DEVAX"""
